summaryrefslogtreecommitdiff
path: root/Master/texmf-dist/doc/latex/dox/dox.el
diff options
context:
space:
mode:
Diffstat (limited to 'Master/texmf-dist/doc/latex/dox/dox.el')
-rw-r--r--Master/texmf-dist/doc/latex/dox/dox.el30
1 files changed, 16 insertions, 14 deletions
diff --git a/Master/texmf-dist/doc/latex/dox/dox.el b/Master/texmf-dist/doc/latex/dox/dox.el
index 7187c71fc43..2de037d5ed7 100644
--- a/Master/texmf-dist/doc/latex/dox/dox.el
+++ b/Master/texmf-dist/doc/latex/dox/dox.el
@@ -1,4 +1,4 @@
;;; dox.el --- AUC-TeX style file for DoX
;; Copyright (C) 2009, 2010, 2017 Didier Verna
@@ -22,21 +22,23 @@
;;; Code:
(TeX-add-style-hook "dox"
- (function
- (lambda ()
- (TeX-add-symbols
- '("doxitem" [ "Options" ]
- "Function name" "Environment name" "Index category name")))))
+ (lambda ()
+ (TeX-add-symbols
+ '("doxitem" [ TeX-arg-key-val (("idxtype") ("macrolike")) ]
+ "Function name" "Environment name" "Index category name"))
+ (when (and (featurep 'font-latex)
+ (eq TeX-install-font-lock 'font-latex-setup))
+ (font-latex-add-keywords '(("doxitem" "[{{{")) 'function)))
+ LaTeX-dialect)
(defun doxitem (envname)
- "Register a new environment ENVNAME with AUC-TeX.
+ "Register a new environment ENVNAME with AUCTeX.
+The effect is to make docTeX mode treat this new environment just
+like the macro and environment ones. Currently, this means
+avoiding inner indentation.
-The effect is to make docTeX mode treat this new environment just like
-the macro and environment ones. Currently, this means avoiding inner
-indentation.
-
-ENVNAME is actually a regexp appearing in a logical group.
-This means that you can register several environments simultaneously
+ENVNAME is actually a regexp appearing in a logical group. This
+means that you can register several environments simultaneously
by means or regexp combination."
(make-local-variable 'docTeX-indent-inner-fixed)
(push (list
@@ -48,7 +50,7 @@ by means or regexp combination."
docTeX-indent-inner-fixed))
(defun doxitems (&rest envnames)
- "Register environments ENVNAMES with AUC-TeX.
+ "Register environments ENVNAMES with AUCTeX.
See the function `doxitem' for more information."
(mapc #'doxitem envnames))
@@ -1,4 +1,4 @@
-;;; dox.el --- AUC-TeX style file for DoX
+;;; dox.el --- AUCTeX style file for DoX
;; Copyright (C) 2009, 2010, 2017 Didier Verna